Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11)

Unified Diff: third_party/lcov/bin/install.sh

Issue 23189008: Upgrades lcov to 1.10, removes lcov-1.9 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Re-adds UNKNOWN suppression Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/lcov/bin/genpng ('k') | third_party/lcov/bin/lcov » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/lcov/bin/install.sh
diff --git a/third_party/lcov/bin/install.sh b/third_party/lcov/bin/install.sh
index 9d4a9daf22e05dbbddcd4456c5c9c84b8b0f1f73..27140f91dd18b1ae3eab10a61f1c262854176355 100755
--- a/third_party/lcov/bin/install.sh
+++ b/third_party/lcov/bin/install.sh
@@ -1,6 +1,6 @@
#!/bin/bash
#
# install.sh [--uninstall] sourcefile targetfile
#
@@ -9,15 +9,17 @@ if test "x$1" == "x--uninstall" ; then
UNINSTALL=true
SOURCE=$2
TARGET=$3
+ shift 3
else
UNINSTALL=false
SOURCE=$1
TARGET=$2
+ shift 2
fi
# Check usage
if test -z "$SOURCE" || test -z "$TARGET" ; then
- echo Usage: install.sh [--uninstall] source target >&2
+ echo Usage: install.sh [--uninstall] source target [install options] >&2
exit 1
fi
@@ -30,8 +32,9 @@ do_install()
{
local SOURCE=$1
local TARGET=$2
+ local PARAMS=$3
- install -D $SOURCE $TARGET
+ install -p -D $PARAMS $SOURCE $TARGET
}
@@ -62,7 +65,7 @@ do_uninstall()
if $UNINSTALL ; then
do_uninstall $SOURCE $TARGET
else
- do_install $SOURCE $TARGET
+ do_install $SOURCE $TARGET "$*"
fi
exit 0
« no previous file with comments | « third_party/lcov/bin/genpng ('k') | third_party/lcov/bin/lcov » ('j') | no next file with comments »
@@ -1,6 +1,6 @@
#!/bin/bash
#
-# install.sh [--uninstall] sourcefile targetfile
+# install.sh [--uninstall] sourcefile targetfile [install options]
#

Powered by Google App Engine
This is Rietveld 408576698